API docs for “spamfighter.txjsonrpc.web.test.test_jsonrpc.JSONRPCTestCase2”

# Class s.t.w.t.t.JSONRPCTestCase2(JSONRPCTestCase):

Part of spamfighter.txjsonrpc.web.test.test_jsonrpc View Source View In Hierarchy

Test with proxy that doesn't add a slash.

Method | proxy | Undocumented

Inherited from JSONRPCTestCase:

Method | setUp | Undocumented
Method | tearDown | Undocumented
Method | testResults | Undocumented
Method | testErrors | Undocumented

def proxy(self): (source)
overrides spamfighter.txjsonrpc.web.test.test_jsonrpc.JSONRPCTestCase.proxy
Undocumented